@@ -96,6 +96,7 @@
 #' })
 #' shinyApp(ui, server)
 #' }
+#'
 #' ## Changing attributes of header and content.
 #' if (interactive()) {
 #' library(shiny)
@@ -123,24 +124,36 @@
 #' }
 #' shinyApp(ui, server)
 #' }
+#'
+#' ## Modal that closes automatically after specific time
 #' if (interactive()) {
 #' library(shiny)
 #' library(shiny.semantic)
-#' shinyApp(
-#'   ui = semanticPage(
-#'     actionButton("show", "Show modal dialog")
-#'   ),
-#'   server = function(input, output) {
-#'     observeEvent(input$show, {
-#'       showModal(modalDialog(
+#' ui <- function() {
+#'   shinyUI(
+#'     semanticPage(
+#'       actionButton("show", "Show modal dialog")
+#'     )
+#'   )
+#' }
+#'
+#' server <- shinyServer(function(input, output, session) {
+#'   observeEvent(input$show, {
+#'     create_modal(
+#'       modal(
+#'         id = "simple-modal",
 #'         title = "Important message",
-#'         "This modal will close after 3 sec.", easyClose = FALSE
-#'       ))
-#'       Sys.sleep(3)
-#'       removeModal()
-#'     })
-#'   }
-#' )
+#'         header = "Example modal",
+#'         content = "This modal will close after 3 sec.",
+#'         footer = NULL,
+#'       )
+#'     )
+#'     Sys.sleep(3)
+#'     hide_modal(id = "simple-modal")
+#'   })
+#' })
+#'
+#' shinyApp(ui = ui(), server = server)
 #' }
 #'
 #' @rdname modal
@@ -263,12 +276,16 @@ attach_rule <- function(id, behavior, target, value) {
 #' @param id ID of the modal that will be displayed.
 #' @param session The \code{session} object passed to function given to
 #'   \code{shinyServer}.
+#' @param asis A boolean indicating if the id must be handled as is (TRUE) or
+#' will be it must be namespaced (FALSE)
 #' @seealso modal
 #'
 #' @rdname show_modal
 #'
 #' @export
-show_modal <- function(id, session = shiny::getDefaultReactiveDomain()) {
+show_modal <- function(id, session = shiny::getDefaultReactiveDomain(),
+                       asis = TRUE) {
+  id <- ifelse(inherits(session, "session_proxy"), session$ns(id), id)
   session$sendCustomMessage("showSemanticModal", list(id = id, action = "show")) # nolint
 }
 
@@ -279,7 +296,9 @@ showModal <- function(ui, session = shiny::getDefaultReactiveDomain()) {
 
 #' @rdname show_modal
 #' @export
-remove_modal <- function(id, session = shiny::getDefaultReactiveDomain()) {
+remove_modal <- function(id, session = shiny::getDefaultReactiveDomain(),
+                         asis = TRUE) {
+  id <- ifelse(inherits(session, "session_proxy"), session$ns(id), id)
   shiny::removeUI(paste0("#", id))
 }
 
@@ -298,6 +317,8 @@ removeModal <- function(session = shiny::getDefaultReactiveDomain()) {
 
 #' @rdname show_modal
 #' @export
-hide_modal <- function(id, session = shiny::getDefaultReactiveDomain()) {
+hide_modal <- function(id, session = shiny::getDefaultReactiveDomain(),
+                       asis = TRUE) {
+  id <- ifelse(inherits(session, "session_proxy"), session$ns(id), id)
   session$sendCustomMessage("showSemanticModal", list(id = id, action = "hide")) # nolint
 }
