@@ -8,13 +8,14 @@ test_that("test slider_input", {
   # number input
   si_str <- as.character(slider_input("slider_input", 10, 0, 20))
   expect_true(grepl(
-    "<div id=\"slider_input\" class=\"ui slider \" data-min=\"0\" data-max=\"20\" data-step=\"1\" data-start=\"10\">",
+    paste("<div id=\"slider_input\" class=\"ui slider ss-slider labeled\" data-min=\"0\"",
+    "data-max=\"20\" data-step=\"1\" data-start=\"10\">"),
     si_str
   ))
 })
 
 test_that("test sliderInput", {
-  expect_error(sliderInput("slider_input"), "\"label\" is missing")
+  expect_error(sliderInput("slider_input"), "\"value\" is missing")
   si_str <- as.character(sliderInput("slider_input", "Label", 10, 0, 20))
   expect_true(grepl(
     "<form class=\"ui form \">\n  <label>Label</label>\n",
@@ -30,11 +31,11 @@ test_that("test range_input", {
   # type
   expect_is(range_input("range_input", 10, 15, 0, 20), "shiny.tag")
   # empty input
-  expect_error(uicalendar())
+  expect_error(range_input())
   # number input
   si_str <- as.character(range_input("range_input", 10, 15, 0, 20))
   expect_true(grepl(paste(
-    "<div id=\"range_input\" class=\"ui range slider \" data-min=\"0\" data-max=\"20\"",
+    "<div id=\"range_input\" class=\"ui range slider ss-slider \" data-min=\"0\" data-max=\"20\"",
     "data-step=\"1\" data-start=\"10\" data-end=\"15\">"
   ), si_str))
 })
